@@ -51,6 +51,9 @@ Carrier Access Billing System
 @item CABS
 Computer Aided Business Simulation
 
+@item CAC
+Channel Access Code (Bluetooth)
+
 @item CAC
 Computer Aided Crime
 
@@ -114,6 +117,9 @@ Computer Aided Logistics
 @item CAL
 Computer Assisted Learning
 
+@item CALEA
+Communications Assistance Law Enforcement Act (USA)
+
 @item CALS
 Computer aided Acquisition and Logistics Support
 
@@ -312,6 +318,9 @@ Constant Bit Rate (ATM, VBR, ABR, UBR, QOS)
 @item CBS
 Certified Banyan Specialist (Banyan, VINES)
 
+@item CBSR
+Candidate BootStrap Router (PIM, BSR, Multicast), "C-BSR"
+
 @item CBT
 Canon Buffer Transmission (Fax)
 
@@ -319,7 +328,7 @@ Canon Buffer Transmission (Fax)
 Computer-Based Training
 
 @item CBT
-Core Based Tree [multicast protocol] (IP, RFC 1949)
+Core Based Tree [multicast protocol] (IP, RFC 1949/2189, ST, Multicast)
 
 @item CBX
 Computerized Branch eXchange (PBX)
@@ -331,7 +340,7 @@ Carbon Copy
 Continuity Cell (ATM)
 
 @item CC
-Country Code (MS-ISDN, GSM, Mobile-Systems)
+Country Code (MS-ISDN, GSM, mobile-systems)
 
 @item CC
 Cross Connector
@@ -352,7 +361,7 @@ Cube Connected Cycles (MP)
 Campus Computer Communication Association (org., USA)
 
 @item CCCH
-Common Control CHannel (GSM, Mobile-Systems)
+Common Control CHannel (GSM, mobile-systems)
 
 @item CCCI
 Center for Cyber Communities Initiative (org., Japan)
@@ -420,6 +429,9 @@ Cache-Coherent Non Uniform Memory Access (SMP, NUMA), "cc-NUMA"
 @item CCP
 Command Console Processor (CP/M)
 
+@item CCP
+Communications Control Program (OS, IBM)
+
 @item CCP
 Compact Communication Products (TPS)
 
@@ -435,6 +447,9 @@ Center for Computer Research in Music and Acoustics (org., Stanford, UK)
 @item CCS
 Cambridge Cybernetic Society (org.)
 
+@item CCS
+Coded Character Set (CCS, Unicode)
+
 @item CCS
 Common Channel Signaling (IN)
 
@@ -490,7 +505,7 @@ Change Directory (DOS, Unix, OS/2)
 Committee Draft (ISO)
 
 @item CD
-Compact Disk
+Compact Disk (CD)
 
 @item CDA
 Communications Decency Act (Internet, USA)
@@ -507,6 +522,9 @@ Connectionless Data Bearer Service
 @item CDBX
 Computerized Digital Branch eXchange (PBX)
 
+@item CDC
+Connected Device Configuration (JVM)
+
 @item CDC
 Control Data Corporation (manufacturer)
 
@@ -517,7 +535,7 @@ Cult of the Dead Cow (org.), "cDc"
 Component Design Document
 
 @item CDDA
-Compact Disk - Digital Audio (CD, digital audio), "CD-DA" 
+Compact Disk - Digital Audio (CD, Digital audio), "CD-DA" 
 
 @item CDDI
 Copper Distributed Data Interface (FDDI, UTP)
@@ -570,6 +588,9 @@ Compact Disk - Magneto Optical (CD), "CD-MO"
 @item CDMS
 Communication Driver Maintenance System (ISDN, HST)
 
+@item CDNC
+Chinese DOMAIN Name Consortium (org., Internet, DOMAIN)
+
 @item CDO
 Collaboration Data Objects (WSH, MS)
 
@@ -577,7 +598,7 @@ Collaboration Data Objects (WSH, MS)
 Cellular Digital Packet Data
 
 @item CDPD
-Cellular Digital Packet Data (Mobile-Systems)
+Cellular Digital Packet Data (mobile-systems)
 
 @item CDR
 Compact Disk - Recordable (CD), "CD-R" 
@@ -648,6 +669,12 @@ Cisco Educational ARCHive (Cisco, WWW)
 @item CEBIT
 welt CEntrum Buero Information Telekommunikation (fair), "CeBIT"
 
+@item CECI
+CICS Enhanced Command Interpreter (IBM, CICS)
+
+@item CEDA
+??? (CICS, IBM)
+
 @item CEDR
 [Microsoft Windows] Compact Edition Driver Repository (MS, Windows, CE)
 
@@ -666,6 +693,12 @@ Card Edge Low Profile [socket]
 @item CELP
 Code Excited Linear Prediction
 
+@item CEM
+Contract Equipment Manufacturer
+
+@item CEMT
+??? (CICS, IBM)
+
 @item CEN
 Comite Europeen de Normalisation (Europe, Brussels)
 
@@ -699,6 +732,9 @@ Computer Emergency Response Team (DARPA, CMU, Internet)
 @item CES
 C-bit Errored Seconds (DS3/E3)
 
+@item CES
+Character Encoding Scheme (CSS, Unicode)
+
 @item CES
 Circuit Emulation Service
 
@@ -717,6 +753,9 @@ Centro de Estudes de Telecomunicoes (org., Portugal)
 @item CF
 Carry Flag (assembler)
 
+@item CF
+Compact Flash [card]
+
 @item CFA
 Center for Architecture (org., JIEO, DISA)
 
@@ -747,6 +786,9 @@ ConFiguration Management (FDDI, SMT)
 @item CFMC
 Committee to Fight Microsoft Corporation (org., MS)
 
+@item CFML
+Cold Fusion Markup Language
+
 @item CFP
 Call For Papers
 
@@ -831,6 +873,9 @@ Check In (RCS)
 @item CI
 Coded Information
 
+@item CI
+Component Interface (DMI)
+
 @item CI
 Configuration Item (CM)
 
@@ -853,13 +898,16 @@ Coordination and Information Center (CSNET)
 Center of Innovative Computer Applications (org.)
 
 @item CICS
-Customer Information Control System (IBM)
+Customer Information Control System (IBM, CICS)
 
 @item CICSESA
-Customer Information Control System/Enterprise Systems Architecture (IBM), "CICS/ESA"
+Customer Information Control System/Enterprise Systems Architecture (IBM, CICS), "CICS/ESA"
+
+@item CICSTS
+Customer Information Control System / Transaction Server (IBM, VSE/ESA), "CICS/TS"
 
 @item CICSVS
-Customer Information Control System / Virtual Storage (IBM), "CICS/VS"
+Customer Information Control System / Virtual Storage (IBM, CICS), "CICS/VS"
 
 @item CID
 Configuration - Installation - Distribution (IBM)
@@ -885,12 +933,18 @@ Component Integration LABoratorieS (org.,, OpenDoc, Apple, IBM, Adobe, ...), CIL
 @item CIM
 Cisco Interactive Mentor (Cisco)
 
+@item CIM
+Common Information Model (DMTF, XML, DMI)
+
 @item CIM
 Computer Integrated Manufacturing
 
 @item CIMOM
 CIM Object Model (CIM)
 
+@item CIMOS
+CIncinnati Milacron Operating System (OS), "CiMOS"
+
 @item CIO
 Cisco Information Online (Cisco, WWW)
 
@@ -906,6 +960,9 @@ Computer Integrated Processing
 @item CIP
 Computer-Investitions-Programm
 
+@item CIPA
+Children's Internet Protection Act (Internet, USA, COPA)
+
 @item CIR
 Committed Information Rate (ATM)
 
@@ -924,6 +981,9 @@ Command Information System (mil., USA)
 @item CIS
 Compuserve Information Systems (network)
 
+@item CIS
+Contact Image Sensor
+
 @item CISC
 Complex Instruction Set Computer (CPU)
 
@@ -963,12 +1023,18 @@ Column Address Strobe Latency (CAS)
 @item CL
 ConnectionLess (CO)
 
+@item CL
+Control Language (IBM, OS/400)
+
 @item CLASS
 Centralized Local Area Selective Signaling
 
 @item CLASS
 Custom Local Area Signaling Service
 
+@item CLDC
+Connected Limited Device Configuration (KVM, CDC)
+
 @item CLE
 Certified Lotus Engineer (Lotus)
 
@@ -984,6 +1050,12 @@ CLear Interrupt (assembler)
 @item CLI
 Command Line Interpreter / Interface (OS)
 
+@item CLI
+Common Language Infrastructure (MS)
+
+@item CLIC
+Chemnitzer LInux Cluster (Linux, Chemnitz), "CLiC"
+
 @item CLIC
 Computer Liability Insurance Coverage
 
@@ -1029,12 +1101,21 @@ CLasS IDentifier (COM)
 @item CLTP
 ConnectionLess Transport Protocol (OSI)
 
+@item CLUG
+Chemnitzer Linux User Group (Chemnitz, user group, Linux)
+
 @item CLUT
 Color LookUp Table (VGA)
 
 @item CLV
 Constant Linear Velocity (CD, MOD)
 
+@item CLX
+Class Library for cross platform (Delphi, Windows, Linux)
+
+@item CM
+Compatibility Mode (PARISC, NM)
+
 @item CM
 Configuration Management
 
@@ -1042,7 +1123,7 @@ Configuration Management
 Configuration Manager (BIOS, PNP)
 
 @item CM
-Connection Management (RR, MM, GSM, Mobile-Systems)
+Connection Management (RR, MM, GSM, mobile-systems)
 
 @item CM2
 Communication Manager /2 (IBM), "CM/2"
@@ -1050,6 +1131,9 @@ Communication Manager /2 (IBM), "CM/2"
 @item CM5
 Connection Machine 5 (TMC)
 
+@item CMAS
+Cambridge Multiple Access System (OS)
+
 @item CMC
 Common Messaging Calls [interface] (XAPIA)
 
@@ -1059,6 +1143,9 @@ Complement Carry Flag (assembler)
 @item CMC
 Computer Mediated Communications [studies centre] (org., USA)
 
+@item CMDS
+Cambridge Model Distributed System (OS)
+
 @item CME
 Component Management Entity
 
@@ -1092,6 +1179,9 @@ Color Management Method (DTP, ICM)
 @item CMMU
 Cache/Memory Management Unit
 
+@item CMO
+Chi Mei Optoelectronic (manufacturer)
+
 @item CMOL
 CMIP Over LLC (OSI, LLC)
 
@@ -1107,6 +1197,9 @@ Cooperative Marketing Partner (DEC)
 @item CMR
 Cell Misinsertion Rate (ATM)
 
+@item CMS
+[Cambridge] / Conversational Monitor System (IBM, OS, VM, VME, VM/ESA, Z/VM)
+
 @item CMS
 Chip Multiprocessor System
 
@@ -1117,10 +1210,10 @@ Code Management System (DEC, CM)
 Color Management System
 
 @item CMS
-Content Management System
+Content Management Software / System
 
 @item CMS
-Conversational Monitor System (IBM, VME)
+Cryptographic Message Syntax (cryptography, RFC 2630)
 
 @item CMT
 Connection ManagemenT (FDDI)
@@ -1138,7 +1231,7 @@ Cyan Magenta Yellow blacK (color system, DTP)
 Communications Network
 
 @item CN
-Connection Management (Mobile-Systems)
+Connection Management (mobile-systems)
 
 @item CN
 Coordination Message (ISO 9646-3, TTCN)
@@ -1282,7 +1375,7 @@ Central Office Equipment
 COE Engineering System (COE)
 
 @item COFDM
-??? (digital audio)
+??? (Digital audio)
 
 @item COFF
 Common Object File Format (Unix)
@@ -1348,7 +1441,7 @@ Concurrent Object Orientated Programming (OOP)
 Character-Oriented Protocol
 
 @item COPA
-Child Online Protection Act (Internet, USA)
+Child Online Protection Act (Internet, USA, CIPA)
 
 @item CORAN
 Communication ORiented Application aNalysis
@@ -1362,15 +1455,27 @@ COmmunity Research and Development Information Service (Europe)
 @item COS
 Card Operating System (OS, ICC)
 
+@item COS
+Cassette Operating System (OS)
+
 @item COS
 Class of Service
 
 @item COS
 Clip On Socket (CPU)
 
+@item COS
+Commercial Operating System (OS, DEC, PDP 11)
+
+@item COS
+Concurrent Operating System (OS, UNIVAC 9200, UNIVAC 9300)
+
 @item COS
 Corporation for Open Systems (org., OSI, user group)
 
+@item COS
+Cray Operating System (OS, Cray)
+
 @item COSA
 COmputerunterstuetzte SAchbearbeitung
 
@@ -1410,11 +1515,14 @@ Connection Processor
 @item CP
 Control Point (IBM, SNA)
 
+@item CP
+Control Program (IBM, OS, VM/ESA, VM)
+
 @item CP
 Coordination Point (ISO 9646-3, TTCN)
 
 @item CPAN
-Comprehensive PERL Archive Network (PERL, FTP)
+Comprehensive PERL Archive Network (PERL)
 
 @item CPC
 Cost Per Copy
@@ -1428,6 +1536,9 @@ Cellular Digital Packet Data
 @item CPE
 Customer Premises Equipment
 
+@item CPF
+Control Program Facility (OS, IBM, S/38)
+
 @item CPGA
 Ceramic Pin Grid Array (CPU)
 
@@ -1452,6 +1563,9 @@ Common Programming Interface for Communications (IBM, SAA, API), "CPI/C"
 @item CPIO
 CoPy In/Out (Unix)
 
+@item CPIRR
+Common Programming Interface Resource Recovery (IBM, SAA)
+
 @item CPL
 Combined Programming Language (DEC, PL/1)
 
@@ -1462,7 +1576,7 @@ Conversational Programming Language (DEC)
 Complex Programmable Logic Device (PLD, IC, RL)
 
 @item CPM
-Control Program for Microcomputers (OS), "CP/M"
+Control Program for Microcomputers (OS, DR), "CP/M"
 
 @item CPM
 Cost Per Minute
@@ -1482,9 +1596,18 @@ Compuserve Packet Network (network)
 @item CPN
 Customer Premises Network
 
+@item CPNET
+Control Program / NETwork (CP/M, OS), "CP/NET"
+
+@item CPNOS
+Control Program / ??? (CP/NET, CP/M, OS), "CP/NOS"
+
 @item CPODA
 Contention Priority Orientated Demand Assignment (MAC, PODA)
 
+@item CPPS
+Card / Paper tape Programming System (OS, IBM)
+
 @item CPS
 Central Processing System
 
@@ -1572,6 +1695,9 @@ Carriage Return - Line Feed (ASCII, DOS)
 @item CRM
 Customer Relationship Management
 
+@item CRP
+Candidate Rendezvous Point (PIM, RP, Multicast), "C-RP"
+
 @item CRP
 Common Reference Platform (PowerPC)
 
@@ -1603,7 +1729,7 @@ Client/Server, "C/S"
 Code Segment [register] (CPU, Intel, assembler)
 
 @item CS
-Coding Scheme (GPRS, Mobile-Systems)
+Coding Scheme (GPRS, mobile-systems)
 
 @item CS
 Computer Science
@@ -1674,6 +1800,9 @@ Cable SELect (EIDE, HD)
 @item CSELT
 Centro Studi E Laboratori Telecomunicazioni [s.p.a.] (org., Italy)
 
+@item CSEM
+Centre Suisse d'Electronique et de Microtecnique (org., Switzerland)
+
 @item CSES
 C-bit Severely Errored Seconds (DS3/E3)
 
@@ -1713,6 +1842,9 @@ Central Schengen Information Systen (SIS, Europe, Strasbourg)
 @item CSKI
 Ceska Spolecnost pro Kybernetiku a Informatiku (org., Tschechien)
 
+@item CSL
+Callable Services Library (IBM, VM/ESA, CMS)
+
 @item CSL
 Computer SoLutions [software gmbh] (Haendler)
 
@@ -1857,6 +1989,9 @@ Computer Telephony Integration
 @item CTM
 Communication Trunk of Medium range Mil., Germany
 
+@item CTOS
+Cassette Tape Operating System (OS, Datapoint)
+
 @item CTR
 [columbia university] Center for Telecommunications Research (org., USA)
 
@@ -1879,7 +2014,10 @@ Conformance Testing Service (OSTC)
 C Topology Specific Module (NEST, MLID, Novell)
 
 @item CTSS
-Compatible / Cray Time Sharing System (Unix, predecessor, OS)
+Compatible Time Sharing System (Unix, predecessor, OS, MIT)
+
+@item CTSS
+Cray TimeSharing System (OS, Cray, LLNL)
 
 @item CTT
 Cartridge Tape Transport
@@ -1905,6 +2043,9 @@ Call Up (Unix)
 @item CUA
 Common User Application
 
+@item CUCUG
+Champaign-Urbana Computer Users Group (org., user group)
+
 @item CUI
 Character User Interface (UI)
 
