@@ -25,10 +25,10 @@ Flow Admission Acknowledge [message] (LFAP)
 Fast Access Btree Structure
 
 @item FAC
-Final Assembly Code (IMEI, GSM, Mobile-Systems)
+Final Assembly Code (IMEI, GSM, mobile-systems)
 
 @item FACCH
-Fast Associated Control CHannel (GSM, DCCH, Mobile-Systems)
+Fast Associated Control CHannel (GSM, DCCH, mobile-systems)
 
 @item FACE
 Framed Access Command Environment (Unix, SVR4)
@@ -36,6 +36,12 @@ Framed Access Command Environment (Unix, SVR4)
 @item FACS
 Firmware ACPI Control Structure (ACPI)
 
+@item FADOS
+Fast Amsterdam Distributed (???) Operating System (OS, FAMP)
+
+@item FADT
+Fixed ACPI Description Table (ACPI)
+
 @item FADU
 File Access Data Unit (FTAM)
 
@@ -43,7 +49,7 @@ File Access Data Unit (FTAM)
 Field Application Engineer
 
 @item FAG
-FernmeldeAnlagenGesetz
+FernmeldeAnlagenGesetz DFUe, Germany
 
 @item FAIS
 Finnish Artificial Intelligence Society (org., Finland, AI)
@@ -57,6 +63,9 @@ FORMEX Applied to Multilingualism in Europe (SGML, Europe)
 @item FAMOS
 Floating gate Avalanche injection Metal Oxide Semiconductor (IC)
 
+@item FAMP
+Fast Amsterdam MultiProcessor
+
 @item FANP
 Flow Attribute Notification Protocol (Toshiba, RFC 2129)
 
@@ -106,7 +115,7 @@ Forschungsinstitut fuer Anwendungsorientierte Wissensverarbeitung (org., KI, Ulm
 Fiber optic Backbone
 
 @item FBAS
-FarbBild-AustastSystem / Farb-Bild-Austast-Synchron-signal (Video)
+FarbBild-AustastSystem / Farb-Bild-Austast-Synchron-signal (video)
 
 @item FBL
 Frame Burst error Length (CD)
@@ -151,7 +160,7 @@ Federal Communications Commission (org., USA)
 Forward Carbon Copy (DFUe)
 
 @item FCCH
-Frequency Correction CHannel (GSM, Mobile-Systems)
+Frequency Correction CHannel (GSM, mobile-systems)
 
 @item FCCN
 Fundacao para a Computacao Cientifica Nacional (org., Portugal)
@@ -189,6 +198,9 @@ Flow Change Request [message] (LFAP)
 @item FCS
 Fast Circuit Switching
 
+@item FCS
+First Customer Ship (IBM)
+
 @item FCS
 Frame Check Sequence (FDDI, Token Ring)
 
@@ -235,7 +247,7 @@ Free Documentation License (GNU)
 Frequency Division Multiplexing (FDM)
 
 @item FDMA
-Frequency Division Multiple Access (Mobile-Systems)
+Frequency Division Multiple Access (mobile-systems)
 
 @item FDO
 Functional Device Object
@@ -265,7 +277,7 @@ Fast Data Enciphering Algorithm (cryptography)
 Far End Block Error (SONET)
 
 @item FEC
-Forward Error Correction (GSM, Mobile-Systems)
+Forward Error Correction (GSM, mobile-systems)
 
 @item FECN
 Forward Explicit Congestion Notification (ATM)
@@ -414,6 +426,9 @@ Federal Information Processing Standard (NIST, USA)
 @item FIR
 Fast IRDA (IRDA)
 
+@item FIR
+Finite Impulse Response (DSP)
+
 @item FIRE
 Flexible Intelligent Routing Engine (3Com)
 
@@ -495,6 +510,9 @@ Flash Memory Manager (Intel)
 @item FMS
 FernMeldeSystem
 
+@item FMS
+FORTRAN Monitor System (OS, IBM 709)
+
 @item FMTEYEWTK
 Far More Than Everything You Ever Wanted To Know (slang, PERL)
 
@@ -612,6 +630,9 @@ Field Programmable Gate Array (RL)
 @item FPI
 Flux Changes per Inch (HDD)
 
+@item FPI
+Formal Public Identifier (DTD, SGML)
+
 @item FPI
 Functional Process Improvement
 
@@ -619,7 +640,7 @@ Functional Process Improvement
 Field Programmable Logic Array
 
 @item FPLMTS
-Future Public Land Mobile Telecommunications System (IN, Mobile-Systems)
+Future Public Land Mobile Telecommunications System (IN, mobile-systems)
 
 @item FPM
 Fast Page Mode [DRAM] (RAM, DRAM)
@@ -717,6 +738,9 @@ For Small Business (Novell)
 @item FSB
 Front Side Bus
 
+@item FSC
+Fujitsu Siemens Computer (manufacturer)
+
 @item FSCK
 File System Consistency checK (Unix)
 
@@ -738,6 +762,9 @@ Frequency Shift Keying (DFUe)
 @item FSM
 Finite State Machine (TTCN, ...)
 
+@item FSM
+Freiwillige Selbstkontrolle Multimedia Org., Germany
+
 @item FSMGDOS
 ??? Graphics Device Operating System (OS, Atari)
 
@@ -747,6 +774,9 @@ Finite State Machine (TTCN, ...)
 @item FSOP
 Full Scale OutPut (FSIP)
 
+@item FSOS
+Free Standing Operating System (OS)
+
 @item FSP
 File Slurping Protocol
 
@@ -756,6 +786,9 @@ File System RunTime Library
 @item FSS
 Fast System Switch (Unix)
 
+@item FSSUTF
+FileSystem Safe UCS Transformation Format (UCS, Unicode), "FSS-UTF"
+
 @item FST
 Flat Square Technology (Hitachi)
 
