@@ -106,7 +106,7 @@ Hard Disk Controller
 High Density Compact Disk (CD, Sony, Phillips)
 
 @item HDD
-Hard Disk Drive
+Hard Disk Drive (HDD)
 
 @item HDD
 Highly Doped Drain (IC, MOSFET)
@@ -133,11 +133,14 @@ High-level Data Link Control (ISO)
 Hardware Device Module (I2O)
 
 @item HDML
-Handheld Device Markup Language (Mobile-Systems, HDTP)
+Handheld Device Markup Language (mobile-systems, HDTP)
 
 @item HDN
 Hochgeschwindigkeits-DatenNetz
 
+@item HDOS
+Heath Disk Operating System (OS, Heath)
+
 @item HDR
 High availability Data Replication (Informix, DB)
 
@@ -151,7 +154,7 @@ High data / bit rate Digital Subscriber Line (BELLCORE, AT&T, DSL)
 High-level Data Specification Language
 
 @item HDTP
-Handheld Device Transport Protocol (Mobile-Systems)
+Handheld Device Transport Protocol (mobile-systems)
 
 @item HDX
 Half DupleX
@@ -192,6 +195,9 @@ Handling the Electronic Representation of mixed text - image Office Documents ba
 @item HES
 Home Electronic System (SNI)
 
+@item HES
+Honeywell Executive System (OS, Honeywell 800)
+
 @item HF
 Have Fun (slang, Usenet, IRC)
 
@@ -280,7 +286,7 @@ High Level Language Application Programming Interface (IBM, API)
 Higher Layer Protocol Identifier
 
 @item HLR
-Home Location Register (LR, GSM, GPRS, Mobile-Systems)
+Home Location Register (LR, GSM, GPRS, mobile-systems)
 
 @item HLS
 Hue, Luminance, Saturation (color system, DTP)
@@ -370,7 +376,7 @@ High Performance FileSystem (OS/2)
 Hewlett Packard Graphics Language (CAD, CAM, HP)
 
 @item HPIB
-Hewlett Packard Interface Bus
+Hewlett Packard Interface Bus (GPIB)
 
 @item HPM
 Hyper Page Mode
@@ -429,11 +435,14 @@ Hue Saturation Brightness (DTP)
 @item HSC
 Hierarchical Storage Controller
 
+@item HSC
+HTML Sucks Completely (HTML, Amiga)
+
 @item HSCDS
 High Speed Cable Data Services
 
 @item HSCSD
-High Speed Circuit Switched Data (GSM, Mobile-Systems)
+High Speed Circuit Switched Data (GSM, mobile-systems)
 
 @item HSDRAM
 ??? Random Access Memory (RAM, DRAM, IC)
@@ -511,7 +520,7 @@ Hyper-g Text Format (Hyper-G)
 Hope This Helps (slang)
 
 @item HTML
-HyperText Markup Language (Internet, WWW, SGML, RFC 1866/1942)
+HyperText Markup Language (Internet, WWW, SGML, RFC 1866/1942, HTML)
 
 @item HTPS
 High Temperature PolySilicon
@@ -543,6 +552,9 @@ Hue-Value-Chroma [model] (Tektronic, DTP)
 @item HVD
 High Voltage Differential [technology] (SCSI)
 
+@item HWMC
+HardWare Motion Compensation
+
 @item HYCH
 Hope You Can Help (slang, Usenet, IRC)
 
