@@ -34,7 +34,7 @@ MACintosh Operating System (Apple, OS), "MacOS"
 Manufacturing Application Control System (SNI)
 
 @item MACS
-Modem Access Control System (MODEM, DES), "M.A.C.S."
+MODEM Access Control System (MODEM, DES, cryptography), "M.A.C.S."
 
 @item MACSBUG
 Motorola Advanced Computer Symbolic deBUGger (Motorola)
@@ -48,12 +48,18 @@ Message Address Directory
 @item MAD
 Militaerischer AbschirmDienst (mil., org.)
 
+@item MADCAP
+Multicast Address Dynamic Client Allocation Protocol (RFC 2730, Multicast)
+
 @item MADE
 Multimedia Application Development Environment (CWI)
 
 @item MADK
 Microsoft Activex Development Kit (ActiveX, MS)
 
+@item MADT
+Multiple APIC Description Table (ACPI, APIC)
+
 @item MAE
 Macintosh Application Environment (Apple, Sun, HPUX)
 
@@ -66,6 +72,9 @@ Microprocessor Architecture for Java Computing [pronounced 'magic'] (Sun, Java)
 @item MAJOUR
 Modular Application for JOURnals (EWS, SGML)
 
+@item MAM
+Multi Access Module
+
 @item MAME
 Multiple Arcade Machine Emulator, "M.A.M.E."
 
@@ -79,13 +88,13 @@ Maintenance Analysis Procedure (IBM)
 Manufacturing Automation Protocol (General Motors)
 
 @item MAP
-Mobile Application Part (MSC, GSM, Mobile-Systems)
+Mobile Application Part (MSC, GSM, mobile-systems)
 
 @item MAP27
 Mobile Access Protocol [for MPT 1327] (MPT 1327), "MAP 27"
 
 @item MAPASE
-Mobile Application Part - Application Service Elements (MAP, MSC, GSM, Mobile-Systems), "MAP-ASE"
+Mobile Application Part - Application Service Elements (MAP, MSC, GSM, mobile-systems), "MAP-ASE"
 
 @item MAPI
 Messaging Application Program Interface (MS, WOSA, API)
@@ -94,7 +103,7 @@ Messaging Application Program Interface (MS, WOSA, API)
 Manufacturing Automation Protocol/Technical Office Protocol, "MAP/TOP" 
 
 @item MAR
-Microprogram Address Register
+Microprogram Address Register (IC)
 
 @item MARC
 MAchine Readable Cataloging [record]
@@ -105,6 +114,9 @@ Multi Agent Systems (AI)
 @item MAS90
 Mittelstands-Anwendungs-System 90 (IBM)
 
+@item MASC
+Multicast Address-Set Claim [protocol] (RFC 2909, Multicast)
+
 @item MASE
 Message Administration Service Element
 
@@ -142,7 +154,7 @@ MailBox
 MegaByte
 
 @item MBAG
-Mercedes-Benz AktienGesellschaft (Anwender)
+Mercedes-Benz AktienGesellschaft (user)
 
 @item MBCMS
 Mercedes-Benz-Computer-Mikrofilm-System (MBAG), "MB-CMS"
@@ -232,7 +244,10 @@ Master Certified Netware Engineer (Novell, Netware)
 ??? [cable modem standard] (org.)
 
 @item MCP
-Master Control Program
+Master Control Program (OS)
+
+@item MCP
+Merlin Convenience Pack (IDB, OS/2)
 
 @item MCP
 Multiport / Multiprotocol Communication Processor
@@ -256,7 +271,7 @@ Material Control System
 Message Conversion System
 
 @item MCS
-Modulation and Coding Scheme (EGPRS, Mobile-Systems)
+Modulation and Coding Scheme (EGPRS, mobile-systems)
 
 @item MCS
 MultiCast Server
@@ -285,6 +300,9 @@ Microsoft Certified Trainer (MS, ATEC)
 @item MCTD
 Mean Cell Transfer Delay (UNI, ATM)
 
+@item MCTS
+Multiple Console Time Sharing System (OS, CAD)
+
 @item MCU
 Management & Cascade Unit (Hub)
 
@@ -324,6 +342,9 @@ Medicated Digest Authentication (HTTP)
 @item MDA
 Monochrome Display Adapter (IBM, PC)
 
+@item MDAC
+Microsoft Data Access Components (MS)
+
 @item MDBMS
 Multidimensional DataBase Management System (DBMS, DB)
 
@@ -349,7 +370,7 @@ MultiDimensional DataBase (DB)
 Medium Dependent Interface (ethernet)
 
 @item MDI
-Mobile Data Initiative (org., GSM, Mobile-Systems)
+Mobile Data Initiative (org., GSM, mobile-systems)
 
 @item MDI
 Multiple Document Interface (MS, Windows)
@@ -417,6 +438,9 @@ Micro-ElectroMechanical System
 @item MERS
 Most Economic Route Selection
 
+@item MERT
+Multiple Environment, Real Time (OS)
+
 @item MES
 Manufacturing Execution System
 
@@ -519,6 +543,9 @@ MOSIX File System (MOSIX, DFSA)
 @item MFT
 Master File Table (NTFS)
 
+@item MFT
+Multiprogramming with a Fixed number of Tasks (IBM, OS, OS/MFT, OS/MVT)
+
 @item MFV
 MehrFrequenzwahlVerfahren
 
@@ -606,6 +633,12 @@ Musical Instruments Digital Interface (MIDI)
 @item MIDL
 Microsoft Interface Definition Language (NT)
 
+@item MIDP
+Mobile Information Device Profile (J2ME)
+
+@item MIDPEG
+Mobile Information Device Profile Expert Group (Sun, AOL, Motorola, NEC, Nokia, Palm, Samsung, Sharp, ...)
+
 @item MIF
 Module Interconnection Facility (Proteus)
 
@@ -642,6 +675,9 @@ Machine Independent MicrOprogramming LAnguage (HDL)
 @item MIN
 Multistage Interconnection Networks
 
+@item MINC
+Multilingual Internet Names Consortium (org., Internet, DOMAIN)
+
 @item MINISTREL
 Models for INformatIon STorage and REtrievaL (OA, BIS, ESPRIT)
 
@@ -663,6 +699,9 @@ Modular Input/Output [architecture] (HP)
 @item MIP
 Multimission Interactive Picture
 
+@item MIP
+Multum In Parvo (3D, SAT)
+
 @item MIPS
 Microprocessor without Interlocked Piped Stages
 
@@ -673,11 +712,14 @@ Million Instructions Per Second (CPU)
 Maximum Information Rate
 
 @item MIR
-Micro-Instruction Register
+Micro-Instruction Register (IC)
 
 @item MIS
 Management Information System
 
+@item MIS
+Mega Iterations per Second
+
 @item MISD
 Multiple Instruction [stream], Single Data [stream] (CPU)
 
@@ -741,6 +783,9 @@ Mailing List Manager [software]
 @item MLMA
 Multi-Level Multi-Access (MAC)
 
+@item MLP
+Meridian Lossless Packaging (DVD, audio)
+
 @item MLP
 MultiLink Point-to-Point Protocol (PPP)
 
@@ -763,7 +808,7 @@ Media Manager (Novell, Netware, SMS)
 Military Message (mil.)
 
 @item MM
-Mobile Management (RR, CM, GSM, Mobile-Systems)
+Mobile Management (RR, CM, GSM, mobile-systems)
 
 @item MMA
 Microcomputer Managers Association (org., USA)
@@ -846,6 +891,9 @@ Module Making System (VMS)
 @item MMS
 Multilevel Mail Server
 
+@item MMS
+Multimedia Message Service
+
 @item MMU
 Mass Memory Unit
 
@@ -897,6 +945,9 @@ Molekulare Optisch-Elektrische Schaltungstraeger
 @item MOESI
 Modified - Owner - Exclusive - Shared - Invalid (AMD)
 
+@item MOF
+Managed Object Format (CIM, DMTF)
+
 @item MOF
 Meta Object Facility
 
@@ -936,9 +987,18 @@ Multiple Original Prints
 @item MOPS
 Million Operations Per Second
 
+@item MOS
+Master Operating System (OS, Varian)
+
 @item MOS
 Metal Oxide Semiconductor (IC)
 
+@item MOS
+Minimum Operating System (OS, UNIVAC 9200, UNIVAC 9300)
+
+@item MOS
+Multiprogramming Operating System (OS, NCR)
+
 @item MOSES
 Major Open Systems Environment Standards
 
@@ -1008,6 +1068,9 @@ MultiPlatform DiskArray
 @item MPDU
 Message Protocol Data Unit (PDU)
 
+@item MPE
+Multi-Programming Executive (OS, HP, HP 3000)
+
 @item MPEG
 Motion Picture Expert Group [old term] (MPEG)
 
@@ -1029,15 +1092,27 @@ Message Passing Interface Forum (manufacturer)
 @item MPL
 Mozilla Public License (Netscape)
 
+@item MPLS
+Multi-Protocol Label Switching (RFC 3031)
+
 @item MPM
 Metra Potential Method
 
+@item MPM
+Multi-user ??? Program for Microcomputers (CP/M, OS, DR), "MP/M"
+
 @item MPM2
 MultiMedia Presentation Manager/2 (OS/2, IBM), "MPM/2"
 
 @item MPML
 Main Profile @@ Main Level (MPEG), "MP@@ML"
 
+@item MPNET
+Multi-user ??? Program / NETwork (MP/M, CP/NET, OS), "MP/NET"
+
+@item MPNOS
+Multi-user ??? Program / ??? (MP/NET, CP/NOS, OS), "MP/NOS"
+
 @item MPOA
 Multi-Protocol Over ATM (ATM)
 
@@ -1113,6 +1188,12 @@ MIDI Processing Unit 401 (Roland, MIDI), "MPU 401"
 @item MPW
 Macintosh Programmers Workshop (Apple)
 
+@item MPX
+MultiProgramming eXecutive (IBM, OS, IBM 1800)
+
+@item MPX
+MultiProgramming eXecutive (OS)
+
 @item MQI
 Message Queueing Interface (IBM)
 
@@ -1131,6 +1212,9 @@ Modified Read (Fax)
 @item MRA
 Multi Resolutions Analysis
 
+@item MRAM
+Magnetoresistive Random Access Memory (IC, RAM)
+
 @item MRB
 Method Request Broker (OMG)
 
@@ -1171,7 +1255,7 @@ Multicommand Required Operational Capability
 ??? Read Only Memory (ROM)
 
 @item MRP
-Material / Manufacturing Resource Palnning
+Material / Manufacturing Resource Planning
 
 @item MRP
 Material Requirement Planning (PPS, CIM)
@@ -1204,7 +1288,7 @@ Meta Signaling (ATM, ???)
 MicroSoft (manufacturer, MS)
 
 @item MS
-Mobile Station (GSM, Mobile-Systems)
+Mobile Station (GSM, mobile-systems)
 
 @item MSA
 Management Service Architecture
@@ -1222,7 +1306,7 @@ Most Significant Bit
 MicroSoft C
 
 @item MSC
-Mobile services Switching Center (PLMN, GSM, GPRS, Mobile-Systems)
+Mobile services Switching Center (PLMN, GSM, GPRS, mobile-systems)
 
 @item MSCDEX
 MicroSoft Compact Disk EXtensions (CD)
@@ -1245,6 +1329,9 @@ Most Significant Digit
 @item MSDE
 MicroSoft Data Engine (MS, DB)
 
+@item MSDE
+Microsoft SQL Server Desktop Engine (MS, SQL)
+
 @item MSDL
 MicroSoft Download Library (MS)
 
@@ -1258,7 +1345,7 @@ MicroSoft Developer Network (Internet, MS)
 MicroSoft Developer Network (MS)
 
 @item MSDOS
-MicroSoft Disk Operating System (MS, OS)
+MicroSoft Disk Operating System (MS, OS, PC)
 
 @item MSE
 MicroSoft Exchange server (MS)
@@ -1282,7 +1369,7 @@ Micro-Star International (manufacturer, Taiwan)
 MicroSoft Internet Explorer (MS, WWW, MSIE)
 
 @item MSISDN
-Mobile Station ISDN Number (PLMN, GSM, Mobile-Systems), "MS-ISDN"
+Mobile Station ISDN Number (PLMN, GSM, mobile-systems), "MS-ISDN"
 
 @item MSIX
 Metered Services Information eXchange [protocol] (Internet, ISP)
@@ -1317,6 +1404,9 @@ Multiple Subscriber Number (Euro-, ISDN)
 @item MSNF
 Multiple Systems Networking Facility (IBM)
 
+@item MSOS
+Mass storage Operating System (OS, CDC)
+
 @item MSP
 Media Signal Processor (Samsung, MMX, ARM)
 
@@ -1326,11 +1416,17 @@ Message Security Protocol
 @item MSP
 Message Send Protocol (RFC 1159)
 
+@item MSP
+Multitasking System Program (OS, Hemenway)
+
+@item MSP7
+Modular System Program /7 (OS, IBM), "MSP/7"
+
 @item MSPI
 M&T Software Partner International [gmbh]
 
 @item MSR
-Machine Specific Register
+Machine Specific Register (IC)
 
 @item MSR
 Mess-, Steuer- und Regelungssysteme
@@ -1339,14 +1435,17 @@ Mess-, Steuer- und Regelungssysteme
 Mobile Support Router (MHP)
 
 @item MSR
-Model Specific Registers (Intel, Pentium)
+Model Specific Register (Intel, Pentium, IC)
 
 @item MSRN
-Mobile Station Roaming Number (MM, HLR, MS-ISDN, GSM, Mobile-Systems)
+Mobile Station Roaming Number (MM, HLR, MS-ISDN, GSM, mobile-systems)
 
 @item MSRPC
 MicroSoft Remote Procedure Call (MS, DCOM), "MS-RPC"
 
+@item MSS
+Maximum Segment Size (TCP, ADSL)
+
 @item MSS
 MIMOLA Software System (MIMOLA)
 
@@ -1375,7 +1474,7 @@ Mannesmann Tally [gmbh] (manufacturer)
 Message Transfer / Type
 
 @item MT
-Mobile Termination (GSM, Mobile-Systems)
+Mobile Termination (GSM, mobile-systems)
 
 @item MT
 Moluccas Time [+0830] (TZ)
@@ -1399,11 +1498,14 @@ Master Test Component (ISO 9646-3, TTCN)
 MIDI Time Code (MIDI)
 
 @item MTD
-Memory Technology Drivers
+Memory Technology Driver (IBM, PC-DOS)
 
 @item MTDA
 Mean Time Data Availability
 
+@item MTDS
+Magnetic Tape Operating System (OS)
+
 @item MTE
 MuTating Engine (Viren), "MtE"
 
@@ -1425,18 +1527,33 @@ Memory Translator Hub (Intel)
 @item MTI
 MIPS Technologies Inc. (manufacturer, SGI)
 
+@item MTJ
+Magnetic Tunnel Junction (MRAM)
+
+@item MTOS
+Magnetic Tape Operating System (OS, Datapoint)
+
 @item MTP
-Message Transfer Part (ISDN, GSM, Mobile-Systems)
+Message Transfer Part (ISDN, GSM, mobile-systems)
 
 @item MTRR
-Memory Type Range Register (CPU, Pentium Pro)
+Memory Type Range Register (CPU, Pentium Pro, IC)
+
+@item MTS
+Magnetic Tape System (OS, HP, HP 2100)
 
 @item MTS
 Message Transfer System (MHS)
 
+@item MTS
+Michigan Terminal System (OS)
+
 @item MTS
 Microsoft Transaction Server (MS, DB, WSH, COM)
 
+@item MTT
+MailTrusT (cryptography)
+
 @item MTTF
 Mean Time To Failure
 
@@ -1450,7 +1567,7 @@ Mean Time to Recovery / Repair / React
 Mean Time Trouble Repair
 
 @item MTU
-Maximum Transmission Unit (SLIP, PPP, IP)
+Maximum Transmission Unit (SLIP, PPP, IP, PPPoE)
 
 @item MTU
 Message Transfer Unit
@@ -1491,6 +1608,9 @@ MULtimedia Office Server (OA, BIS, ESPRIT)
 @item MUMPS
 Massachusetts general hospital Multi-Programming System
 
+@item MUMPS
+Multi-User Multi-Programming System ??? (OS, DEC)
+
 @item MUPAD
 Multi Processing Algebra Data [tool] (Uni Paderborn, Germany, CAS), "MuPAD"
 
@@ -1498,7 +1618,7 @@ Multi Processing Algebra Data [tool] (Uni Paderborn, Germany, CAS), "MuPAD"
 Multi-User Shared Hallucination (MUD)
 
 @item MUSICAM
-Masking-pattern adapted Universal Subband Integrated Coding And Multiplexing (MPEG, digital audio)
+Masking-pattern adapted Universal Subband Integrated Coding And Multiplexing (MPEG, Digital audio)
 
 @item MUT
 Master Upper Tester (ISO 9646-3, TTCN)
@@ -1533,7 +1653,7 @@ Most Valuable Professional [bonus program] (MS)
 Magnalink Variable Resource Compression Algorithm (PPP, RFC 1975)
 
 @item MVS
-Multiple Virtual Storage (IBM, OS)
+Multiple Virtual Storage (IBM, OS, OS/MVS)
 
 @item MVS
 Multiple Virtual System (OS)
@@ -1553,6 +1673,9 @@ Multiple Virtual Storage/Time Sharing Option (IBM), "MVS/TSO"
 @item MVSXA
 Multiple Virtual Storage/eXtended Architecture, "MVS/XA" 
 
+@item MVT
+Multiprogramming with a Variable number of Tasks (IBM, OS/MVT, OS)
+
 @item MWS
 Management WorkStation
 
@@ -1571,6 +1694,9 @@ Multimedia eXtension Connector
 @item MZ
 Mark Zbikowski (MS-DOS, MCB)
 
+@item MZAP
+Multicast-scope Zone Announcement Protocol (RFC 2776, Multicast)
+
 @end table
 
 
