@@ -9,17 +9,23 @@
 @c Additional explanations are included in [square brackets]
 
 @table @asis
+@item RA
+Registration Authority (PKI, ITU)
+
 @item RA
 Remote Access (BBS)
 
 @item RACE
 Research and technology development in Advanced Communications technologies in Europe (Europe, predecessor, CORDIS)
 
+@item RACE
+Rowbased ASCII Compatible Encoding (ASCII, Internet, DOMAIN, VeriSign/NSI)
+
 @item RACF
-Resource Access Control Facility (IBM)
+Resource Access Control Facility (IBM, MVS/ESA)
 
 @item RACH
-Random Access CHannel (GSM, CCCH, Mobile-Systems)
+Random Access CHannel (GSM, CCCH, mobile-systems)
 
 @item RAD
 Rapid Access Disk
@@ -54,6 +60,9 @@ Rutherford Appleton Laboratory (org., UK)
 @item RAM
 Random Access Memory (RAM, IC)
 
+@item RAM
+Rarely Adequate Memory (slang)
+
 @item RAMDAC
 Random Access Memory Digital to Analog Converter (RAM)
 
@@ -120,6 +129,9 @@ Remote Bridge Hub
 @item RBL
 Realtime Blackhole List (Internet, SPAM)
 
+@item RBM
+Realtime Batch Monitor (OS, Xerox)
+
 @item RBMS
 Remote Bridge Management Software
 
@@ -136,7 +148,7 @@ Region Co-ordinator (FidoNet)
 Release Candidate (MS)
 
 @item RC
-Return Code
+Return Code (REXX, ...)
 
 @item RC
 Routing Control
@@ -202,7 +214,7 @@ Resource Construction Set
 Revision Control System (Unix, CM, GNU)
 
 @item RCTC
-Rewritable Consumer Time Code (Video)
+Rewritable Consumer Time Code (video)
 
 @item RCTL
 Resistor-Capacitor-Transistor Logic
@@ -291,6 +303,12 @@ Relative Distinguished Name (X.500)
 @item RDNCRC
 Research Data Network Cooperative Research Centre (org., Australia)
 
+@item RDO
+??? (CICS, IBM)
+
+@item RDO
+??? (CICS, IBM)
+
 @item RDO
 Remote Data Objects (DB)
 
@@ -300,6 +318,9 @@ Reliable Datagram Protocol
 @item RDP
 Remote Desktop Protocol (MS)
 
+@item RDP
+Remote Display Protocol (MS, Windows NT, ASP)
+
 @item RDR
 Request Data with Reply (Feldbus)
 
@@ -342,6 +363,9 @@ REGular EXpressions (GREP, EMACS, ...)
 @item REGIS
 REmote Graphics Instruction Set
 
+@item REGTP
+REGulierungsbehoerde fuer Telekommunikation und Post Org., Germany, "RegTP"
+
 @item REM
 Remote Equipment Module
 
@@ -370,10 +394,10 @@ Resolution Enhancement Technology (HP), "REt"
 Rare Earth / Transition Metal (MO), "RE/TM"
 
 @item REXX
-Restructured EXtended eXecutor [language] (IBM, SAA)
+Restructured EXtended eXecutor [language] (IBM, SAA, ANSI)
 
 @item RF
-Radio Frequency (Mobile-Systems)
+Radio Frequency (mobile-systems)
 
 @item RFA
 Request for Assistance (Internet)
@@ -417,6 +441,9 @@ Remote File Management System
 @item RFNM
 Request For Next Message (IMP)
 
+@item RFP
+Request for Package (Linux, Debian)
+
 @item RFP
 Request For Proposal (Internet)
 
@@ -429,6 +456,9 @@ Remote File Sharing (AT&T, Unix)
 @item RFS
 Remote File System
 
+@item RFS
+REXX File System (REXX, CICS, VSAM, IBM)
+
 @item RFT
 Request For Technology (OSF)
 
@@ -474,12 +504,12 @@ Routing Information Field (Token Ring)
 @item RIFF
 Resource Interchange File Format (MS, IBM, MM)
 
-@item RIFF
-Resource Interchange File Format (MS, MM)
-
 @item RIG
 Related Interest Group
 
+@item RIG
+Rochester Intelligent Gateway (OS)
+
 @item RII
 Routing Information Indicator
 
@@ -495,6 +525,9 @@ Rambus Inline Memory Module (Rambus, IC)
 @item RIO
 Redistributed Internet Objects (S3, VRML, Internet)
 
+@item RIOCP
+??? (OS), "RIO/CP "
+
 @item RIP
 Raster Image Processor (DTP)
 
@@ -537,6 +570,9 @@ Resolution Improvement TECHnology (Epson)
 @item RITSEC
 Regional Information Technology and Software Engineering Center
 
+@item RJ45
+Registered Jack 45 (cable)
+
 @item RJE
 Remote Job Entry (IBM, Internet, RFC 407)
 
@@ -556,7 +592,7 @@ Real Life (DFUe, Usenet, IRC)
 Reconfigurable Logic (RL)
 
 @item RLC
-Radio Link Control (GPRS, Mobile-Systems)
+Radio Link Control (GPRS, mobile-systems)
 
 @item RLE
 Run-Length Encoded
@@ -571,7 +607,7 @@ Run Length Limited [encoding]
 Remote LAN Nodes (LAN)
 
 @item RLP
-Radio Link Protocol (GSM, Mobile-Systems)
+Radio Link Protocol (GSM, mobile-systems)
 
 @item RLP
 Resource Location Protocol (Internet, RFC 887)
@@ -582,6 +618,9 @@ Received Line Signal
 @item RLSD
 Received Line Signal Detector
 
+@item RLSFB
+Read Last Spool File Buffer (IBM, VM/ESA, CP)
+
 @item RLT
 Remote Line Test
 
@@ -597,6 +636,9 @@ Remote Memory Administration System
 @item RMATS
 Remote Maintenance Administration and Traffic
 
+@item RMCOS
+Ryan-McFarland COBOL (????) Operating System (OS, COBOL), "RM/COS"
+
 @item RMF
 Resource Measurement Facility (IBM, MVS)
 
@@ -625,7 +667,10 @@ Richard Matthew Stallman (FSF, EMACS)
 Raw Magnetic Tape (Unix)
 
 @item RMT
-Rexxware Migration Tool (Simware, REXX)
+Reliable Multicast Transport (IETF, WG, Multicast)
+
+@item RMT
+REXXware Migration Tool (Simware, REXX)
 
 @item RMT
 Ring ManagemenT (FDDI, SMT)
@@ -642,9 +687,18 @@ Raw Native Interface (MS, Java)
 @item RNOC
 Regional Network Operations Center
 
+@item RNPRSFP
+Read Next PRint Spool File Block (IBM, VM/ESA, CP)
+
+@item RNPUFSB
+Read Next PUnch Spool File Block (IBM, VM/ESA, CP)
+
 @item RNR
 Receive Not Ready (LAPB)
 
+@item RNSB
+Read Next Spool Buffer (IBM, VM/ESA, CP)
+
 @item RNUI
 Remote Network User Identification (Datex-P)
 
@@ -705,6 +759,9 @@ Rolling On The Floor Laughing My Ass Off (slang, Usenet, IRC)
 @item RP
 Relay Party (IRC)
 
+@item RP
+Rendezvous Point (PIM, Multicast)
+
 @item RPA
 Remote Phrase Authentication
 
@@ -723,6 +780,12 @@ Remote Peripheral Equipment
 @item RPELTP
 Regular Pulse Excitation with Long-Term Prediction [loop] (LPC), "RPE-LTP"
 
+@item RPF
+RePeat active File (IBM, VM/ESA, CP)
+
+@item RPF
+Reverse Path Forwarding (PIM, Multicast)
+
 @item RPG
 Report Program Generator
 
@@ -751,13 +814,13 @@ Reverse Polish Notation
 Relative Processor Performance (CPU, Cray)
 
 @item RPS
-Realtime Programming System
+Realtime Programming System (OS, IBM)
 
 @item RQBE
 Relational Query By Example (DB, QBE)
 
 @item RR
-Radio Resource management (MM, CM, GSM, Mobile-Systems)
+Radio Resource management (MM, CM, GSM, mobile-systems)
 
 @item RRAS
 Routing and Remote Access Service (MS, Windows NT)
@@ -810,6 +873,12 @@ Remote Source Control System
 @item RSCS
 Remote Spooling Communications Subsystem (IBM, VM, NJE)
 
+@item RSDP
+Root System Description Pointer (ACPI)
+
+@item RSDT
+Root System Description Table (ACPI)
+
 @item RSE
 Removable Storage Elements
 
@@ -819,6 +888,15 @@ Research and Systems Engineering
 @item RSF
 Remote Support Facility
 
+@item RSF
+ReStart active File (IBM, VM/ESA, CP)
+
+@item RSFD
+Retrieve Subsequent File Descriptor (IBM, VM/ESA, CP)
+
+@item RSFDNPR
+Retrieve Subsequent File Descriptor Not Previously Retrieved (IBM, VM/ESA, CP)
+
 @item RSH
 Remote SHell (Unix, BSD, Shell)
 
@@ -867,14 +945,11 @@ Resource reSerVation Protocol (IP)
 @item RSX
 Realistic Sound eXperience (Intel, audio)
 
-@item RSX11D
-Resource Sharing eXecutive - 11D (DEC), "RSX-11D"
-
-@item RSX11M
-Resource Sharing eXecutive - 11M (DEC), "RSX-11M"
+@item RSX11
+Resource Sharing eXecutive - 11 (DEC, OS, PDP 11), "RSX-11"
 
 @item RSX3D
-Realistic Sound eXperience - 3D (Intel, Audio, VRML), "RSX-3D"
+Realistic Sound eXperience - 3D (Intel, audio, VRML), "RSX-3D"
 
 @item RT
 Register Transfer
@@ -909,6 +984,9 @@ Real Time Clock
 @item RTC
 Real-Time Command
 
+@item RTCP
+Real Time Control Protocol (RTP)
+
 @item RTCS
 Real Time Computer System
 
@@ -927,12 +1005,21 @@ Real Time Data Handling System
 @item RTE
 Real Time Execution
 
+@item RTE
+Real Time Executive (OS, HP, HP 2000)
+
 @item RTE
 Remote Terminal Emulation
 
 @item RTE
 Run Time Environment
 
+@item RTE6VM
+Real Time Executive - 6 / Virtual Memory (OS, HP, RTE, HP 1000), "RTE-6/VM"
+
+@item RTEX
+Real Time EXecutive (OS, Interdata)
+
 @item RTF
 Rich Text Format
 
@@ -942,6 +1029,9 @@ Read The Fucking FAQ (slang, Usenet)
 @item RTFM
 Read The Flaming / Fucking Manual (slang, Usenet, IRC)
 
+@item RTG
+Real Time Gambling
+
 @item RTG
 Real Time Geometry (manufacturer)
 
@@ -974,14 +1064,29 @@ Release To Manufacture / Market
 @item RTM
 Remote Test Module
 
+@item RTMOS
+Real Time Multiprogramming Operating System (OS, GE)
+
 @item RTMP
 Routing Table Maintenance Protocol (AppleTalk)
 
+@item RTMS
+Real Time Multiprogramming System (???) (OS)
+
+@item RTOS
+Real Time Operating System (OS, Interdata, Prime, ...)
+
+@item RTOS16
+Real Time Operating System - 16 (OS, Digico), "RTOS-16"
+
+@item RTOS360
+Real Time Operating System /360 (IBM, OS, S/360), "RTOS/360"
+
 @item RTOSUH
 Real Time Operating System - Universitaet Hannover (OS), "RTOS-UH"
 
 @item RTP
-Real Time Protocol (Internet, RFC 1889/1890)
+Real Time Protocol (Internet, RFC 1889/1890, RTCP)
 
 @item RTS
 Real Time System
@@ -1002,7 +1107,7 @@ Reliable Transfer Service Element (OSI)
 RealTime System Manager
 
 @item RTSP
-Real Time Streaming Protocol (TV, WWW)
+Real Time Streaming Protocol (TV, WWW, UDP, TCP/IP, RDP, Multicast)
 
 @item RTT
 Round-Trip Time
@@ -1010,18 +1115,33 @@ Round-Trip Time
 @item RTTI
 Run-Time Type Identification (ANSI)
 
+@item RTTM
+Round-Trip Time Measurements (TCP, satellite)
+
+@item RTTS
+Real Time Task Scheduler (OS, August Systems)
+
 @item RTTY
 Radio Tele TYpe
 
 @item RTU
 Real Time Unix (Unix)
 
+@item RTUX
+Real Time UniX (OS, Emerge Systems)
+
 @item RTV
 Real Time Video
 
 @item RTVBR
 RealTime Variable Bit Rate (VBR, ATM), "rt-VBR"
 
+@item RTX
+Real Time eXecutive (OS)
+
+@item RTX16
+Real Time eXecutive - 16 (OS, Honeywell, ...), "RTX-16"
+
 @item RUA
 Remote User Agent
 
